<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsChoose extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-choose';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Choose Area', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'choose' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_choose',
			[
				'label' => esc_html__( 'Choose Area', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Sub Heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Content', 'bdevs-elementor' ),
				'default'     => __( 'It is Content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'option1',
			[
				'label'       => esc_html__( 'Option 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'icon1',
			[
				'label'       => esc_html__( 'Icon 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'option2',
			[
				'label'       => esc_html__( 'Option 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'icon2',
			[
				'label'       => esc_html__( 'Icon 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'option3',
			[
				'label'       => esc_html__( 'Option 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'icon3',
			[
				'label'       => esc_html__( 'Icon 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'option4',
			[
				'label'       => esc_html__( 'Option 4', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'icon4',
			[
				'label'       => esc_html__( 'Icon 4', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'price_title',
			[
				'label'       => esc_html__( 'Price Title', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'price_subtitle',
			[
				'label'       => esc_html__( 'Price Subtitle', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => esc_html__( 'Link', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'button',
			[
				'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'dynamic'     => [ 'active' => true ],
				'default'     => esc_html__( '' , 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		

		$this->end_controls_section();


		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_sub_heading',
			[
				'label'   => esc_html__( 'Show Sub Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		

		$this->start_controls_section(
			'section_content_button',
			[
				'label'     => esc_html__( 'Button', 'bdevs-elementor' ),
				'condition' => [
					'show_button' => 'yes',
				],
			]
		);

		$this->add_control(
			'button_text',
			[
				'label'       => esc_html__( 'Button Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Read More', 'bdevs-elementor' ),
				'placeholder' => esc_html__( 'Read More', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'        => Controls_Manager::ICON,
				'label_block' => true,
			]
		);

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings); ?>

            <section class="choose-area pt-120 pb-120 p-relative" style="background:#f5f5f5;">             
            	<div class="chosse-img wow fadeInRight animated" data-animation="fadeInRight animated" data-delay=".2s"></div>
            	<div class="container">
            		<div class="row">
            			<div class="col-xl-6">
            				<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
            				<div class="s-about-img p-relative">
            					<img src="<?php echo wp_kses_post($settings['image']['url']); ?>" alt="img">
            				</div>
            				<?php endif; ?>	
            			</div>
            			<div class="col-xl-6">
            				<div class="choose-wrap">
            					<div class="section-title w-title left-align mb-35 wow fadeInDown animated" data-animation="fadeInDown animated" data-delay=".2s">
            						<?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_sub_heading'] )): ?>
            							<span><?php echo wp_kses_post($settings['sub_heading']); ?></span>
            						<?php endif; ?>	
            						<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
            							<h2><?php echo wp_kses_post($settings['heading']); ?></h2>
            						<?php endif; ?>	
            					</div>
            					<div class="choose-content wow fadeInUp animated" data-animation="fadeInDown animated" data-delay=".2s">
            						<?php if (( '' !== $settings['content'] ) && ( $settings['show_button'] )) : ?>
            							<p><?php echo wp_kses_post($settings['content']); ?></p>
									<?php endif; ?>	
            						<div class="choose-list mt-20 mb-20">
            							<ul>
            								<?php if ( '' !== $settings['option1'] ) : ?>
            								<li>
												<i class="<?php echo wp_kses_post($settings['icon1']); ?>"></i>
												<span><?php echo wp_kses_post($settings['option1']); ?></span>
											</li>
											<?php endif; ?>
											<?php if ( '' !== $settings['option2'] ) : ?>
											<li>
												<i class="<?php echo wp_kses_post($settings['icon2']); ?>"></i>
												<span><?php echo wp_kses_post($settings['option2']); ?></span>
											</li>
											<?php endif; ?>
											<?php if ( '' !== $settings['option3'] ) : ?>
											<li>
												<i class="<?php echo wp_kses_post($settings['icon3']); ?>"></i>
												<span><?php echo wp_kses_post($settings['option3']); ?></span>
											</li>
											<?php endif; ?>
											<?php if ( '' !== $settings['option4'] ) : ?>
											<li>
												<i class="<?php echo wp_kses_post($settings['icon4']); ?>"></i>
												<span><?php echo wp_kses_post($settings['option4']); ?></span>
											</li>
											<?php endif; ?>
            							</ul>
            						</div>									
            						<?php if ( '' !== $settings['price_title'] ) : ?>  
            							<h3><?php echo wp_kses_post($settings['price_title']); ?></h3>
            						<?php endif; ?>
            						<?php if ( '' !== $settings['price_subtitle'] ) : ?>  
            							<h2><?php echo wp_kses_post($settings['price_subtitle']); ?><h2>
            						<?php endif; ?>
            						<?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>  
            						<div class="choose-btn mt-30">
            							<a href="<?php echo wp_kses_post($settings['link']); ?>" class="btn"><?php echo wp_kses_post($settings['button']); ?></a>
            						</div>
            						<?php endif; ?>
            					</div>
            				</div>
            			</div>
            		</div>
            	</div>
            </section>
	<?php
	}

}