<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsAbout extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-about';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'About', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'about' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_features',
			[
				'label' => esc_html__( 'About', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'about_type_1' => esc_html__( 'About Type 1', 'bdevs-elementor' ),
					'about_type_2' => esc_html__( 'About Type 2', 'bdevs-elementor' ),
				],
				'default'   => 'about_type_1',
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'About Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your About Image', 'bdevs-elementor' ),
			]
		);	

		$this->add_control(
			'image_desc',
			[
				'label'       => __( 'Image Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Image Description', 'bdevs-elementor' ),
				'default'     => __( 'It is Image Description', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'title',
			[
				'label'       => __( 'Title', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Title', 'bdevs-elementor' ),
				'default'     => __( 'It is Title', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is sub heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'desc',
			[
				'label'       => __( 'Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
				'default'     => __( 'It is content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => __( 'Link', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link', 'bdevs-elementor' ),
				'default'     => __( 'It is link', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'button',
			[
				'label'       => __( 'Text Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),
				'default'     => __( 'It is button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_sub_title',
			[
				'label'   => esc_html__( 'Show Sub Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		$chose_style = $settings['chose_style'];
		extract($settings); ?>
	
		<?php if( $chose_style == 'about_type_1' ): ?>
		<section id="about" class="about-area about-p pt-120 pb-120 p-relative">
            <div class="container">
                <div class="row align-items-center">
				<div class="col-lg-6">
                        <div class="s-about-img p-relative">
                        	<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
                            <img src="<?php echo wp_kses_post($settings['image']['url']); ?>" alt="img">
                            <?php endif; ?>	
                            <div class="about-text second-about">
                            	<?php if ( '' !== $settings['image_desc'] ): ?>
                                <span><?php echo wp_kses_post($settings['image_desc']); ?></span>
                                <?php endif; ?>	
                            </div>
                        </div>
                    </div>
				<div class="col-lg-6">
                        <div class="about-content s-about-content pl-30">
                            <div class="about-title second-atitle">
                            	<?php if ( '' !== $settings['title'] ): ?>
                                	<span><?php echo wp_kses_post($settings['title']); ?></span>
                                <?php endif; ?>	
                                <?php if (( '' !== $settings['heading'] ) && ( $settings['show_title'] )): ?>
                                	<h2><?php echo wp_kses_post($settings['heading']); ?></h2>
                                <?php endif; ?>	
                                <?php if ( '' !== $settings['sub_heading'] ) : ?>
                                	<p><span></span><?php echo wp_kses_post($settings['sub_heading']); ?></p>
                                <?php endif; ?>	
                            </div>
                            <?php if (( '' !== $settings['desc'] ) && ( $settings['show_content'] )) : ?>
                            	<p><?php echo wp_kses_post($settings['desc']); ?></p>
                            <?php endif; ?>	
                            <?php if ( '' !== $settings['button'] ): ?>
                            	<a href="<?php echo wp_kses_post($settings['link']); ?>" class="btn"><?php echo wp_kses_post($settings['button']); ?></a>
                            <?php endif; ?>	
                        </div>
                    </div>
                </div>
            </div>
        </section>
        <?php elseif( $chose_style == 'about_type_2' ): ?>
        	<section id="about" class="about-area about-p pt-120 pb-120 p-relative">
                <div class="container">
                    <div class="row align-items-center">
					<div class="col-lg-6">
                            <div class="about-content s-about-content pl-30">
                                <div class="about-title second-atitle">
                                   <?php if ( '' !== $settings['title'] ): ?>
                                	<span><?php echo wp_kses_post($settings['title']); ?></span>
                                <?php endif; ?>	
                                <?php if (( '' !== $settings['heading'] ) && ( $settings['show_title'] )): ?>
                                	<h2><?php echo wp_kses_post($settings['heading']); ?></h2>
                                <?php endif; ?>	
                                <?php if ( '' !== $settings['sub_heading'] ) : ?>
                                	<p><span></span><?php echo wp_kses_post($settings['sub_heading']); ?></p>
                                <?php endif; ?>	
	                            </div>
	                            <?php if (( '' !== $settings['desc'] ) && ( $settings['show_content'] )) : ?>
	                            	<p><?php echo wp_kses_post($settings['desc']); ?></p>
	                            <?php endif; ?>	
	                            <?php if ( '' !== $settings['button'] ): ?>
	                            	<a href="<?php echo wp_kses_post($settings['link']); ?>" class="btn"><?php echo wp_kses_post($settings['button']); ?></a>
	                            <?php endif; ?>	
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="s-about-img p-relative">
                        	<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
                            <img src="<?php echo wp_kses_post($settings['image']['url']); ?>" alt="img">
                            <?php endif; ?>	
                            <div class="about-text second-about">
                            	<?php if ( '' !== $settings['image_desc'] ): ?>
                                <span><?php echo wp_kses_post($settings['image_desc']); ?></span>
                                <?php endif; ?>	
                            </div>
                        </div>
                        </div>
                        
                    </div>
                </div>
            </section>
        <?php endif; ?>
	<?php
	}

}