<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsPlans extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-plans';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Plans Area', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'plans' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_plans',
			[
				'label' => esc_html__( 'Plans', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Plans Tabs', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Tabs #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [				
					[
						'name'        => 'tab_name',
						'label'       => esc_html__( 'Tab Name', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Name' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_id',
						'label'       => esc_html__( 'Tab ID', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab ID' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'    => 'active',
						'label'   => esc_html__( 'Active', 'bdevs-elementor' ),
						'type'    => Controls_Manager::SWITCHER,
						'default' => 'yes',
					],
				],
			]
		);

		$this->add_control(
			'tabs_2',
			[
				'label' => esc_html__( 'Plans Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Items #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [	
					[
						'name'    => 'active_2',
						'label'   => esc_html__( 'Active', 'bdevs-elementor' ),
						'type'    => Controls_Manager::SWITCHER,
						'default' => 'yes',
					],
					[
						'name'        => 'tab_id',
						'label'       => esc_html__( 'Tab ID', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab ID' , 'bdevs-elementor' ),
						'label_block' => true,
					],		
					[
						'name'        => 'tab_content',
						'label'       => esc_html__( 'Tab Content', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Content' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_option',
						'label'       => esc_html__( 'Tab Option', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Option' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'    => 'image',
						'label'   => esc_html__( 'Plans Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
					],	
				],
			]
		);

		$this->end_controls_section();




		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_sub_heading',
			[
				'label'   => esc_html__( 'Show Sub Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->end_controls_section();

		

		$this->start_controls_section(
			'section_content_button',
			[
				'label'     => esc_html__( 'Button', 'bdevs-elementor' ),
				'condition' => [
					'show_button' => 'yes',
				],
			]
		);

		$this->add_control(
			'button_text',
			[
				'label'       => esc_html__( 'Button Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Read More', 'bdevs-elementor' ),
				'placeholder' => esc_html__( 'Read More', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'        => Controls_Manager::ICON,
				'label_block' => true,
			]
		);

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		?>

            	<section class="apartments pt-120 pb-90">
            		<div class="container">
            			<div class="row justify-content-center">
            				<div class="col-xl-8 col-lg-10">
            					<div class="section-title text-center pl-40 pr-40 mb-80 wow fadeInDown animated" data-animation="fadeInDown animated" data-delay=".2s">
									<?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_sub_heading'] )): ?>
            						<span><?php echo wp_kses_post($settings['sub_heading']); ?></span>
            						<?php endif; ?>
            						<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
            						<h2><?php echo wp_kses_post($settings['heading']); ?></h2>
            						<?php endif; ?>
            					</div>
            				</div>
            			</div>
            			<div class="row">
            				<div class="col-lg-3">
            				</div>
            				<div class="col-lg-6">
            					<nav>
            						<div class="nav nav-tabs nav-fill" id="nav-tab" role="tablist">
									<?php foreach ( $settings['tabs'] as $item ) : ?>
										<?php if (( '' !== $item['tab_name'] ) && ( $item['active'] )): ?>
            								<a class="nav-item nav-link active" id="<?php echo wp_kses_post($item['tab_id']); ?>-tab" data-toggle="tab" href="#<?php echo wp_kses_post($item['tab_id']); ?>" role="tab" aria-controls="<?php echo wp_kses_post($item['tab_id']); ?>" aria-selected="true"><?php echo wp_kses_post($item['tab_name']); ?></a>
            							<?php else : ?>
            								<a class="nav-item nav-link" id="<?php echo wp_kses_post($item['tab_id']); ?>-tab" data-toggle="tab" href="#<?php echo wp_kses_post($item['tab_id']); ?>" role="tab" aria-controls="<?php echo wp_kses_post($item['tab_id']); ?>" aria-selected="false"><?php echo wp_kses_post($item['tab_name']); ?></a>
            							<?php endif; ?>
            							<?php
            						endforeach;
            						?>
            						</div>
            					</nav>
            				</div>
            				<div class="col-lg-3">
            				</div>
            				<div class="col-lg-12 ">
            					<div class="tab-content py-3 px-3 px-sm-0 mt-50" id="nav-tabContent">
									<?php foreach ( $settings['tabs_2'] as $item ) : ?>
									<?php if ( $item['active_2'] ): ?>
            							<div class="tab-pane fade show active" id="<?php echo wp_kses_post($item['tab_id']); ?>" role="tabpanel" aria-labelledby="<?php echo wp_kses_post($item['tab_id']); ?>-tab">
            						<?php else : ?>
            							<div class="tab-pane fade" id="<?php echo wp_kses_post($item['tab_id']); ?>" role="tabpanel" aria-labelledby="<?php echo wp_kses_post($item['tab_id']); ?>-tab">
            						<?php endif; ?>
            							<div class="row">						
            								<div class="col-lg-6">
            									<?php if ( '' !== $item['tab_content'] ) : ?>
            									<p><?php echo wp_kses_post($item['tab_content']); ?></p> 
            									<?php endif; ?>
            									<?php if ( '' !== $item['tab_option'] ) : ?>    
            									<ul>
            										<?php echo wp_kses_post($item['tab_option']); ?>
            									</ul>
            									<?php endif; ?>
            								</div>
            								<div class="col-lg-6">
            									<?php if ( '' !== $item['image']['url'] ): ?>
            									<div class="apartments-img">
            										<img src="<?php echo wp_kses_post($item['image']['url']); ?>" alt="floor-chart"/>
            									</div>
            									<?php endif; ?>
            								</div>
            							</div>
            						</div>
            						<?php
            					endforeach;
            					?>
            					</div>
								
            				</div>
            			</div>
            		</div>
            	</div>
            </div>
        </section>
	<?php
	}

}